from typing import Optional, Union

from pydantic import BaseModel, Field


class APIConfig(BaseModel):
    model_config = {"validate_assignment": True}

    base_path: str = "/"
    verify: Union[bool, str] = True
    access_token: Optional[str] = None

    def get_access_token(self) -> Optional[str]:
        return self.access_token

    def set_access_token(self, value: str):
        self.access_token = value


class HTTPException(Exception):
    def __init__(self, status_code: int, message: str):
        self.status_code = status_code
        self.message = message
        super().__init__(f"{status_code} {message}")

    def __str__(self):
        return f"{self.status_code} {self.message}"



from typing import *

from pydantic import BaseModel, Field


class ValidationError(BaseModel):
    """
    ValidationError model
    """

    model_config = {"populate_by_name": True, "validate_assignment": True}

    loc: List[Union[str, int]] = Field(validation_alias="loc")

    msg: str = Field(validation_alias="msg")

    type: str = Field(validation_alias="type")



from typing import *

from pydantic import BaseModel, Field


class OAuth2Token(BaseModel):
    """
    OAuth2Token model
        An OAuth2 token model with secrets stored as SecretStr.
    """

    model_config = {"populate_by_name": True, "validate_assignment": True}

    access_token: str = Field(validation_alias="access_token")

    id_token: Optional[Union[str, None]] = Field(validation_alias="id_token", default=None)

    refresh_token: Optional[Union[str, None]] = Field(validation_alias="refresh_token", default=None)

    expires_in: int = Field(validation_alias="expires_in")

    scope: Optional[Union[str, None]] = Field(validation_alias="scope", default=None)

    token_type: str = Field(validation_alias="token_type")



from typing import *

import httpx

from ..api_config import APIConfig, HTTPException
from ..models import *


def get_by_connection_oauth2_token_get(
    api_config_override: Optional[APIConfig] = None, *, created_by: str, tenant_id: str
) -> ManagedOAuth2Token:
    api_config = api_config_override if api_config_override else APIConfig()

    base_path = api_config.base_path
    path = f"/oauth2-token"

    headers = {
        "Content-Type": "application/json",
        "Accept": "application/json",
        "Authorization": f"Bearer { api_config.get_access_token() }",
    }

    query_params: Dict[str, Any] = {}
    query_params = {key: value for (key, value) in query_params.items() if value is not None}

    with httpx.Client(base_url=base_path, verify=api_config.verify) as client:
        response = client.request(
            "get",
            httpx.URL(path),
            headers=headers,
            params=query_params,
        )

    if response.status_code != 200:
        raise HTTPException(
            response.status_code,
            f"get_by_connection_oauth2_token_get failed with status code: {response.status_code}",
        )

    body = None if 200 == 204 else response.json()

    return ManagedOAuth2Token(**body) if body is not None else ManagedOAuth2Token()


def create_oauth2_token_post(
    api_config_override: Optional[APIConfig] = None, *, data: CreateOAuth2TokenRequest
) -> ManagedOAuth2Token:
    api_config = api_config_override if api_config_override else APIConfig()

    base_path = api_config.base_path
    path = f"/oauth2-token"

    headers = {
        "Content-Type": "application/json",
        "Accept": "application/json",
        "Authorization": f"Bearer { api_config.get_access_token() }",
    }

    query_params: Dict[str, Any] = {}
    query_params = {key: value for (key, value) in query_params.items() if value is not None}

    with httpx.Client(base_url=base_path, verify=api_config.verify) as client:
        response = client.request(
            "post",
            httpx.URL(path),
            headers=headers,
            params=query_params,
            json=data.dict(),
        )

    if response.status_code != 201:
        raise HTTPException(
            response.status_code,
            f"create_oauth2_token_post failed with status code: {response.status_code}",
        )

    body = None if 201 == 204 else response.json()

    return ManagedOAuth2Token(**body) if body is not None else ManagedOAuth2Token()


def delete_by_connection_oauth2_token_delete(
    api_config_override: Optional[APIConfig] = None, *, created_by: str, tenant_id: str
) -> None:
    api_config = api_config_override if api_config_override else APIConfig()

    base_path = api_config.base_path
    path = f"/oauth2-token"

    headers = {
        "Content-Type": "application/json",
        "Accept": "application/json",
        "Authorization": f"Bearer { api_config.get_access_token() }",
    }

    query_params: Dict[str, Any] = {}
    query_params = {key: value for (key, value) in query_params.items() if value is not None}

    with httpx.Client(base_url=base_path, verify=api_config.verify) as client:
        response = client.request(
            "delete",
            httpx.URL(path),
            headers=headers,
            params=query_params,
        )

    if response.status_code != 204:
        raise HTTPException(
            response.status_code,
            f"delete_by_connection_oauth2_token_delete failed with status code: {response.status_code}",
        )

    body = None if 204 == 204 else response.json()

    return None


def get_one_oauth2_token__id__get(api_config_override: Optional[APIConfig] = None, *, id: str) -> ManagedOAuth2Token:
    api_config = api_config_override if api_config_override else APIConfig()

    base_path = api_config.base_path
    path = f"/oauth2-token/{id}"

    headers = {
        "Content-Type": "application/json",
        "Accept": "application/json",
        "Authorization": f"Bearer { api_config.get_access_token() }",
    }

    query_params: Dict[str, Any] = {}
    query_params = {key: value for (key, value) in query_params.items() if value is not None}

    with httpx.Client(base_url=base_path, verify=api_config.verify) as client:
        response = client.request(
            "get",
            httpx.URL(path),
            headers=headers,
            params=query_params,
        )

    if response.status_code != 200:
        raise HTTPException(
            response.status_code,
            f"get_one_oauth2_token__id__get failed with status code: {response.status_code}",
        )

    body = None if 200 == 204 else response.json()

    return ManagedOAuth2Token(**body) if body is not None else ManagedOAuth2Token()


def delete_one_oauth2_token__id__delete(api_config_override: Optional[APIConfig] = None, *, id: str) -> None:
    api_config = api_config_override if api_config_override else APIConfig()

    base_path = api_config.base_path
    path = f"/oauth2-token/{id}"

    headers = {
        "Content-Type": "application/json",
        "Accept": "application/json",
        "Authorization": f"Bearer { api_config.get_access_token() }",
    }

    query_params: Dict[str, Any] = {}
    query_params = {key: value for (key, value) in query_params.items() if value is not None}

    with httpx.Client(base_url=base_path, verify=api_config.verify) as client:
        response = client.request(
            "delete",
            httpx.URL(path),
            headers=headers,
            params=query_params,
        )

    if response.status_code != 204:
        raise HTTPException(
            response.status_code,
            f"delete_one_oauth2_token__id__delete failed with status code: {response.status_code}",
        )

    body = None if 204 == 204 else response.json()

    return None



from typing import *

from pydantic import BaseModel, Field

from .ValidationError import ValidationError


class HTTPValidationError(BaseModel):
    """
    HTTPValidationError model
    """

    model_config = {"populate_by_name": True, "validate_assignment": True}

    detail: Optional[List[Optional[ValidationError]]] = Field(validation_alias="detail", default=None)



from typing import *

from pydantic import BaseModel, Field

from .OAuth2Token import OAuth2Token


class CreateOAuth2TokenRequest(BaseModel):
    """
    CreateOAuth2TokenRequest model
    """

    model_config = {"populate_by_name": True, "validate_assignment": True}

    created_by: str = Field(validation_alias="created_by")

    tenant_id: str = Field(validation_alias="tenant_id")

    name: Optional[Union[str, None]] = Field(validation_alias="name", default=None)

    oauth2_token: OAuth2Token = Field(validation_alias="oauth2_token")

    expires_at: Optional[Union[str, None]] = Field(validation_alias="expires_at", default=None)



from typing import *

from pydantic import BaseModel, Field


class ManagedOAuth2Token(BaseModel):
    """
    ManagedOAuth2Token model
    """

    model_config = {"populate_by_name": True, "validate_assignment": True}

    updated_at: str = Field(validation_alias="updated_at")

    created_by: Optional[Union[str, None]] = Field(validation_alias="created_by", default=None)

    created_at: str = Field(validation_alias="created_at")

    id: Optional[str] = Field(validation_alias="id", default=None)

    name: Optional[Union[str, None]] = Field(validation_alias="name", default=None)

    tenant_id: str = Field(validation_alias="tenant_id")

    access_token: str = Field(validation_alias="access_token")

    id_token: Optional[Union[str, None]] = Field(validation_alias="id_token", default=None)

    refresh_token: Optional[Union[str, None]] = Field(validation_alias="refresh_token", default=None)

    expires_in: int = Field(validation_alias="expires_in")

    scope: Optional[Union[str, None]] = Field(validation_alias="scope", default=None)

    token_type: str = Field(validation_alias="token_type")

    expires_at: Optional[Union[str, None]] = Field(validation_alias="expires_at", default=None)
